@@ -1,5 +1,8 @@
+import logging
 from typing import Optional, Generator, TypeVar, Generic
 from .graph import Node
+from ..logging_.utils import get_logger
+logger = get_logger(__name__)
 
 T = TypeVar('T')
 
@@ -11,6 +14,7 @@ class Stack(Generic[T]):
     def __init__(self) -> None:
         self.head: Optional[Node[T]] = None
         self.size = 0
+        logger.debug("Stack initialized")
 
     def push(self, value: T):
         """push an item to the stack
@@ -18,12 +22,16 @@ class Stack(Generic[T]):
         Args:
             value (Any): item to push
         """
+        logger.debug("Pushing value to stack: %s", value)
         if self.head is None:
             self.head = Node(value)
+            logger.debug("Created first node in stack")
         else:
             new_head = Node(value, self.head)
             self.head = new_head
+            logger.debug("Added new head node to stack")
         self.size += 1
+        logger.debug("Stack size is now: %s", self.size)
 
     def pop(self) -> T:
         """pop an item from the stack
@@ -35,7 +43,9 @@ class Stack(Generic[T]):
             res = self.head.data  # type:ignore
             self.size -= 1
             self.head = self.head.next  # type:ignore
+            logger.debug("Popped value from stack: %s, remaining size: %s", res, self.size)
             return res
+        logger.warning("Attempted to pop from empty stack")
         raise RuntimeError("Can't pop from an empty stack")
 
     def peek(self) -> Optional[T]:
@@ -45,8 +55,11 @@ class Stack(Generic[T]):
             Optional[T]
         """
         if self.is_empty():
+            logger.debug("Peek called on empty stack")
             return None
-        return self.head.data  # type:ignore
+        result = self.head.data  # type:ignore
+        logger.debug("Peeked at stack top: %s", result)
+        return result
 
     def __len__(self) -> int:
         return self.size
