@@ -1,5 +1,8 @@
 import json
+import logging
 from .decorators import validate
+from .logging_.utils import get_logger
+logger = get_logger(__name__)
 
 
 @validate  # type:ignore # type:ignore
@@ -12,7 +15,10 @@ def dict_to_json(dct: dict) -> str:
     Returns:
         str: the json as string
     """
-    return json.dumps(dct, indent=4)
+    logger.debug("Converting dict with %d keys to JSON", len(dct))
+    result = json.dumps(dct, indent=4)
+    logger.debug("JSON conversion completed, result length: %d", len(result))
+    return result
 
 
 @validate  # type:ignore
@@ -25,7 +31,10 @@ def json_to_dict(json_str: str) -> dict:
     Returns:
         dict: a python dict from the json
     """
-    return json.loads(json_str)
+    logger.debug("Converting JSON string (length: %d) to dict", len(json_str))
+    result = json.loads(json_str)
+    logger.debug("JSON parsing completed, dict has %d keys", len(result))
+    return result
 
 
 __all__ = [
