@@ -1,7 +1,10 @@
 import functools
+import logging
 from typing import Callable, Any, TypeVar
 import threading
 from .validate import validate
+from ..logging_.utils import get_logger
+logger = get_logger(__name__)
 
 from ..versioned_imports import ParamSpec
 
@@ -21,13 +24,19 @@ def atomic(func: FuncT) -> FuncT:
     Returns:
         Callable: the thread safe function
     """
+    logger.debug("Making function %s atomic (thread-safe)", func.__name__)
     lock = threading.Lock()
 
     @functools.wraps(func)
     def wrapper(*args, **kwargs) -> Any:
+        logger.debug("Acquiring lock for atomic function %s", func.__name__)
         with lock:
-            return func(*args, **kwargs)
+            logger.debug("Executing atomic function %s", func.__name__)
+            result = func(*args, **kwargs)
+            logger.debug("Atomic function %s completed", func.__name__)
+            return result
 
+    logger.debug("Atomic decorator applied to %s", func.__name__)
     return wrapper
 
 
