@@ -1,7 +1,10 @@
 import functools
+import logging
 from typing import Callable, Optional, TypeVar
 from .validate import validate
 from ..versioned_imports import ParamSpec
+from ..logging_.utils import get_logger
+logger = get_logger(__name__)
 
 T = TypeVar("T")
 P = ParamSpec("P")
@@ -23,22 +26,31 @@ def attach(before: Optional[Callable] = None, after: Optional[Callable] = None)
     Returns:
         Callable: the decorated result
     """
+    logger.debug("Creating attach decorator with before=%s, after=%s", before, after)
     if before is None and after is None:
+        logger.error("Both before and after functions are None")
         raise ValueError("You must supply at least one function")
 
     def attach_deco(func: FuncT) -> FuncT:
+        logger.debug("Applying attach decorator to function %s", func.__name__)
         if not callable(func):
+            logger.error("Object %s is not callable", func)
             raise ValueError("attach must decorate a function")
 
         @functools.wraps(func)
         def wrapper(*args, **kwargs):
+            logger.debug("Executing attached function %s", func.__name__)
             if before is not None:
+                logger.debug("Calling before function: %s", before.__name__)
                 before()
             res = func(*args, **kwargs)
             if after is not None:
+                logger.debug("Calling after function: %s", after.__name__)
                 after()
+            logger.debug("Attached function %s completed", func.__name__)
             return res
 
+        logger.debug("Attach decorator applied to %s", func.__name__)
         return wrapper
 
     return attach_deco
