@@ -1,3 +1,4 @@
+import logging
 from typing import Callable, cast, Any, TypeVar, Dict, List
 import inspect
 import functools
@@ -6,6 +7,9 @@ from ..functions import isoftype, isoneof, isoneof_strict
 from ..exceptions import OverloadDuplication, OverloadNotFound
 from .deprecate import deprecate
 from ..versioned_imports import ParamSpec
+from ..logging_.utils import get_logger
+
+logger = get_logger(__name__)
 
 T = TypeVar("T")
 P = ParamSpec("P")
