@@ -7,3 +7,7 @@ from .powerset import *
 from .multiloop import *
 from .flatten import *
 from .subseteq import *
+from .parallel_for import *
+from .foreach import *
+from .factorial import *
+from .partition import *
