@@ -1,5 +1,9 @@
+import logging
 import threading
 from typing import TypeVar, Callable
+from ..logging_.utils import get_logger
+
+logger = get_logger(__name__)
 
 T = TypeVar("T")
 Consumer = Callable[[T], None]
@@ -16,13 +20,19 @@ def parallel_for(func: Consumer[T], *args: T, wait: bool = True) -> None:
     Returns:
 
     """
+    logger.info("Starting parallel execution of %s with %s arguments, wait=%s", func.__name__, len(args), wait)
     # this is safer... What if some other threads that were running will also end in the meantime?
     threads = [threading.Thread(target=func, args=[arg]) for arg in args]
+    
     for t in threads:
         t.start()
+    
     if wait:
         for t in threads:
             t.join()
+        logger.info("All threads completed successfully")
+    else:
+        logger.info("Threads started, not waiting for completion")
     # before = threading.active_count()
     # for arg in args:
     #     threadify(func)(arg)
