@@ -1,4 +1,8 @@
+import logging
 from typing import Generator, Callable, Any
+from ..logging_.utils import get_logger
+
+logger = get_logger(__name__)
 
 
 def generate_except(generator: Generator[Any, None, None],
@@ -12,9 +16,17 @@ def generate_except(generator: Generator[Any, None, None],
     Yields:
         Generator[Any, None, None]: filtered generator
     """
+    logger.info("Starting generate_except filtering")
+    items_processed = 0
+    items_yielded = 0
+    
     for i, value in enumerate(generator):
+        items_processed += 1
         if not binary_consumer(i, value):
+            items_yielded += 1
             yield value
+    
+    logger.info("generate_except completed: processed %s items, yielded %s items", items_processed, items_yielded)
 
 
 def generate_when(generator: Generator[Any, None, None],
@@ -28,9 +40,17 @@ def generate_when(generator: Generator[Any, None, None],
     Yields:
         Generator[Any, None, None]: filtered generator
     """
+    logger.info("Starting generate_when filtering")
+    items_processed = 0
+    items_yielded = 0
+    
     for i, value in enumerate(generator):
+        items_processed += 1
         if binary_consumer(i, value):
+            items_yielded += 1
             yield value
+    
+    logger.info("generate_when completed: processed %s items, yielded %s items", items_processed, items_yielded)
 
 
 __all__ = [
