@@ -1,4 +1,8 @@
+import logging
 from ..backoff_strategy import BackOffStrategy
+from ...logging_.utils import get_logger
+
+logger = get_logger(__name__)
 
 
 class LinerBackoffStrategy(BackOffStrategy):
@@ -8,7 +12,8 @@ class LinerBackoffStrategy(BackOffStrategy):
         def inner() -> float:
             nonlocal attempt
             attempt += 1
-            return initial + additive_term * (attempt - 1)
+            backoff_time = initial + additive_term * (attempt - 1)
+            return backoff_time
 
         super().__init__(inner)
 
