@@ -1,7 +1,11 @@
+import logging
 import sys, os
 from typing import Optional, Tuple, List
 from ..context_managers import TemporaryFile
 import random
+from ..logging_.utils import get_logger
+
+logger = get_logger(__name__)
 
 
 class LayeredCommand:
@@ -40,12 +44,15 @@ class LayeredCommand:
         LayeredCommand._class_prev_instance = self
         self._executor = os.system
         self._has_entered: bool = False
+        logger.info("LayeredCommand initialized with command: '%s', prev_instance: %s", self._command, prev_instance is not None)
 
     def __enter__(self):
         self._open()
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
+        if exc_type is not None:
+            logger.warning("LayeredCommand context exited with exception: %s: %s", exc_type.__name__, exc_val)
         if self.prev is self._cur_class_prev_instance:
             LayeredCommand._class_prev_instance = self.prev
 
@@ -81,8 +88,10 @@ class LayeredCommand:
             command_verbose: Optional[bool] = None
     ) -> Tuple[int, List[str], List[str]]:
         if not self._has_entered:
+            logger.error("LayeredCommand must be used with a context manager")
             raise RuntimeError(
                 "LayeredCommand must be used with a context manager. Use as: `with LayeredCommand(...) as l1:`")
+        
         capture_stdout = self._merge_values(command_capture_stdout, self._instance_capture_stdout,
                                           self.class_capture_stdout)
         capture_stderr = self._merge_values(command_capture_stderr, self._instance_capture_stderr,
@@ -91,6 +100,8 @@ class LayeredCommand:
                                            self.class_raise_on_fail)
 
         command = self._build_command(*commands)
+        logger.info("Executing command: %s", command)
+        
         if not capture_stdout and not capture_stderr:
             code = self._executor(command)
             self._error(raise_on_fail and code != 0, command, code, command_verbose)
@@ -99,6 +110,7 @@ class LayeredCommand:
         letters = "abcdefghijklmnopqrstuvwxyz"
         prefix = "".join(random.choices(letters, k=10)) + f"_{LayeredCommand._id}"
         LayeredCommand._id += 1
+        
         with TemporaryFile.random(prefix=prefix, suffix="stdout.log") as stdout:
             with TemporaryFile.random(prefix=prefix, suffix="stderr.log") as stderr:
                 if capture_stdout:
